.. -*- encoding: utf-8 -*-

.. |pg.copyrighted-header| replace::

   This is a *copyrighted* Project Gutenberg eBook, details
   below.

.. _pg-header:

.. container:: noindent pgheader language-en pg_boilerplate

   This ebook is for the use of anyone anywhere in the United States
   and most other parts of the world at no cost and with almost no
   restrictions whatsoever. You may copy it, give it away or re-use it
   under the terms of the `Project Gutenberg License`_ included with
   this ebook or online at https://www.gutenberg.org/license. If you
   are not located in the United States, you'll have to check the laws
   of the country where you are located before using this ebook.

   |pg.copyrighted-header|

   .. vspace:: 2

   .. _pg-machine-header:

   .. container:: noindent white-space-pre-line

      |pg.machine-header|

   .. vspace:: 2

   .. _pg-start-line:

   \*\*\* START OF THIS PROJECT GUTENBERG EBOOK |pg.upcase-title| \*\*\*

   .. vspace:: 4

   .. _pg-produced-by:

   |pg.produced-by|

   .. vspace:: 1

   |pg.credits|
